@@ -53,58 +53,6 @@ fn add_managed_types(substitutions: &mut SubstitutionsMap) {
 }
 
 fn add_special_methods(substitutions: &mut SubstitutionsMap) {
-    substitutions.add_substitution(
-        quote!(.managed_into()),
-        quote!(.managed_into(self.type_manager())),
-    );
-
-    substitutions.add_substitution(
-        quote!(BigUint::zero()),
-        quote!(self.types().big_uint_zero()),
-    );
-    substitutions.add_substitution(quote!(BigUint::from), quote!(self.types().big_uint_from));
-    substitutions.add_substitution(quote!(BigInt::zero()), quote!(self.types().big_int_zero()));
-    substitutions.add_substitution(quote!(BigInt::from), quote!(self.types().big_int_from));
-    substitutions.add_substitution(
-        quote!(ManagedBuffer::new()),
-        quote!(self.types().managed_buffer_new()),
-    );
-    substitutions.add_substitution(
-        quote!(ManagedBuffer::from),
-        quote!(self.types().managed_buffer_from),
-    );
-    substitutions.add_substitution(
-        quote!(ManagedVec::new()),
-        quote!(self.types().managed_vec_new()),
-    );
-    substitutions.add_substitution(
-        quote!(ManagedVec::from_single_item),
-        quote!(self.types().managed_vec_from_single_item),
-    );
-    substitutions.add_substitution(
-        quote!(ManagedVec::from),
-        quote!(self.types().managed_vec_from),
-    );
-    substitutions.add_substitution(
-        quote!(ManagedMultiResultVec::new()),
-        quote!(self.types().managed_multi_result_vec_new()),
-    );
-    substitutions.add_substitution(
-        quote!(TokenIdentifier::egld()),
-        quote!(self.types().token_identifier_egld()),
-    );
-    substitutions.add_substitution(
-        quote!(TokenIdentifier::from),
-        quote!(self.types().token_identifier_from),
-    );
-    substitutions.add_substitution(
-        quote!(ManagedAddress::zero()),
-        quote!(self.types().managed_address_zero()),
-    );
-    substitutions.add_substitution(
-        quote!(ManagedAddress::from),
-        quote!(self.types().managed_address_from),
-    );
     substitutions.add_substitution(
         quote!(.unwrap_or_signal_error()),
         quote!(.unwrap_or_signal_error(self.raw_vm_api())),
